pub struct CheckResult {
pub check_name: String,
pub check_description: String,
pub score: f32,
pub weight: u8,
pub problems: Vec<Problem>,
pub total_checks: usize,
pub status: ResultCode,
}Expand description
The result of an individual check
Fields
check_name: StringThe name of the check
check_description: StringA description of what the check does and why
score: f32The score for the check from 0.0 to 1.0
weight: u8The weight of the check in the overall score for language support
problems: Vec<Problem>The problems found during the check
total_checks: usizeThe total number of sub-tests run
status: ResultCodeThe overall status of the check
Implementations
Sourceimpl CheckResult
impl CheckResult
Sourcepub fn summary_result(&self) -> String
pub fn summary_result(&self) -> String
Describe the result in a sentence